ReadMoreTxt class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReadMoreTxt
Constructors
-
ReadMoreTxt(String? data, {Key? key, ValueNotifier<
bool> ? isCollapsed, String? preDataText, String? postDataText, TextStyle? preDataTextStyle, TextStyle? postDataTextStyle, String trimExpandedText = 'show less', String trimCollapsedText = 'read more', Color? colorClickableText, int trimLength = 240, int trimLines = 2, TrimMode trimMode = TrimMode.length, TextStyle? moreStyle, TextStyle? lessStyle, String delimiter = '$_kEllipsis ', TextStyle? delimiterStyle, List<Annotation> ? annotations, bool isExpandable = true, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, Widget? customCollapsedWidget, Widget? customExpandedWidget}) -
const
-
ReadMoreTxt.rich(TextSpan? richData, {Key? key, TextSpan? richPreData, TextSpan? richPostData, ValueNotifier<
bool> ? isCollapsed, String trimExpandedText = 'show less', String trimCollapsedText = 'read more', Color? colorClickableText, int trimLength = 240, int trimLines = 2, TrimMode trimMode = TrimMode.length, TextStyle? moreStyle, TextStyle? lessStyle, String delimiter = '$_kEllipsis ', TextStyle? delimiterStyle, bool isExpandable = true, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, Widget? customCollapsedWidget, Widget? customExpandedWidget}) -
const
Properties
-
annotations
→ List<
Annotation> ? -
final
- colorClickableText → Color?
-
final
- customCollapsedWidget → Widget?
-
NEW — User can pass any widget for show more / show less
final
- customExpandedWidget → Widget?
-
final
- data → String?
-
final
- delimiter → String
-
final
- delimiterStyle → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isCollapsed
→ ValueNotifier<
bool> ? -
final
- isExpandable → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lessStyle → TextStyle?
-
final
- locale → Locale?
-
final
- moreStyle → TextStyle?
-
final
- overflow → TextOverflow?
-
final
- postDataText → String?
-
final
- postDataTextStyle → TextStyle?
-
final
- preDataText → String?
-
final
- preDataTextStyle → TextStyle?
-
final
- richData → TextSpan?
-
final
- richPostData → TextSpan?
-
final
- richPreData → TextSpan?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
final
- semanticsLabel → String?
-
final
- softWrap → bool?
-
final
- strutStyle → StrutStyle?
-
final
- style → TextStyle?
-
final
- textAlign → TextAlign?
-
final
- textDirection → TextDirection?
-
final
- textHeightBehavior → TextHeightBehavior?
-
final
- textScaler → TextScaler?
-
final
- textWidthBasis → TextWidthBasis?
-
final
- trimCollapsedText → String
-
final
- trimExpandedText → String
-
final
- trimLength → int
-
final
- trimLines → int
-
final
- trimMode → TrimMode
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ReadMoreTxt> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited